@@ -56,12 +56,11 @@
             delta_t = i
           )
           names(est) <- varnames
-          out <- list(
+          list(
             delta_t = i,
             est = est,
             thetahatstar = thetahatstar
           )
-          return(out)
         }
       )
     } else {
@@ -88,12 +87,11 @@
             delta_t = i
           )
           names(est) <- varnames
-          out <- list(
+          list(
             delta_t = i,
             est = est,
             thetahatstar = thetahatstar
           )
-          return(out)
         }
       )
     }
@@ -117,14 +115,13 @@
           delta_t = i
         )
         names(est) <- varnames
-        out <- list(
+        list(
           delta_t = i,
           est = est,
           thetahatstar = thetahatstar
         )
-        return(out)
       }
     )
   }
-  return(output)
+  output
 }
