@@ -39,12 +39,10 @@
       phis <- parallel::mclapply(
         X = seq_len(R),
         FUN = function(i) {
-          return(
-            .MCPhiI(
-              phi = phi,
-              vcov_phi_vec_l = t(chol(vcov_phi_vec)),
-              test_phi = test_phi
-            )
+          .MCPhiI(
+            phi = phi,
+            vcov_phi_vec_l = t(chol(vcov_phi_vec)),
+            test_phi = test_phi
           )
         },
         mc.cores = ncores
@@ -78,12 +76,11 @@
             colnames(phi),
             "interval"
           )
-          out <- list(
+          list(
             delta_t = i,
             est = est,
             thetahatstar = thetahatstar
           )
-          return(out)
         }
       )
     } else {
@@ -102,12 +99,10 @@
         cl = cl,
         X = seq_len(R),
         fun = function(i) {
-          return(
-            .MCPhiI(
-              phi = phi,
-              vcov_phi_vec_l = t(chol(vcov_phi_vec)),
-              test_phi = test_phi
-            )
+          .MCPhiI(
+            phi = phi,
+            vcov_phi_vec_l = t(chol(vcov_phi_vec)),
+            test_phi = test_phi
           )
         }
       )
@@ -140,12 +135,11 @@
             colnames(phi),
             "interval"
           )
-          out <- list(
+          list(
             delta_t = i,
             est = est,
             thetahatstar = thetahatstar
           )
-          return(out)
         }
       )
     }
@@ -158,12 +152,10 @@
     phis <- lapply(
       X = seq_len(R),
       FUN = function(i) {
-        return(
-          .MCPhiI(
-            phi = phi,
-            vcov_phi_vec_l = t(chol(vcov_phi_vec)),
-            test_phi = test_phi
-          )
+        .MCPhiI(
+          phi = phi,
+          vcov_phi_vec_l = t(chol(vcov_phi_vec)),
+          test_phi = test_phi
         )
       }
     )
@@ -195,14 +187,13 @@
           colnames(phi),
           "interval"
         )
-        out <- list(
+        list(
           delta_t = i,
           est = est,
           thetahatstar = thetahatstar
         )
-        return(out)
       }
     )
   }
-  return(output)
+  output
 }
