@@ -41,12 +41,10 @@
       phis <- parallel::mclapply(
         X = seq_len(R),
         FUN = function(i) {
-          return(
-            .MCPhiSigmaI(
-              theta = theta,
-              vcov_theta = vcov_theta,
-              test_phi = test_phi
-            )
+          .MCPhiSigmaI(
+            theta = theta,
+            vcov_theta = vcov_theta,
+            test_phi = test_phi
           )
         },
         mc.cores = ncores
@@ -61,15 +59,13 @@
                            from,
                            to,
                            med) {
-              return(
-                .MedStd(
-                  phi = x[[1]],
-                  sigma = x[[2]],
-                  delta_t = delta_t,
-                  from = from,
-                  to = to,
-                  med = med
-                )
+              .MedStd(
+                phi = x[[1]],
+                sigma = x[[2]],
+                delta_t = delta_t,
+                from = from,
+                to = to,
+                med = med
               )
             },
             delta_t = i,
@@ -102,12 +98,11 @@
             "indirect",
             "interval"
           )
-          out <- list(
+          list(
             delta_t = i,
             est = est,
             thetahatstar = thetahatstar
           )
-          return(out)
         }
       )
     } else {
@@ -126,12 +121,10 @@
         cl = cl,
         X = seq_len(R),
         fun = function(i) {
-          return(
-            .MCPhiSigmaI(
-              theta = theta,
-              vcov_theta = vcov_theta,
-              test_phi = test_phi
-            )
+          .MCPhiSigmaI(
+            theta = theta,
+            vcov_theta = vcov_theta,
+            test_phi = test_phi
           )
         }
       )
@@ -146,15 +139,13 @@
                            from,
                            to,
                            med) {
-              return(
-                .MedStd(
-                  phi = x[[1]],
-                  sigma = x[[2]],
-                  delta_t = delta_t,
-                  from = from,
-                  to = to,
-                  med = med
-                )
+              .MedStd(
+                phi = x[[1]],
+                sigma = x[[2]],
+                delta_t = delta_t,
+                from = from,
+                to = to,
+                med = med
               )
             },
             delta_t = i,
@@ -186,12 +177,11 @@
             "indirect",
             "interval"
           )
-          out <- list(
+          list(
             delta_t = i,
             est = est,
             thetahatstar = thetahatstar
           )
-          return(out)
         }
       )
     }
@@ -204,12 +194,10 @@
     phis <- lapply(
       X = seq_len(R),
       FUN = function(i) {
-        return(
-          .MCPhiSigmaI(
-            theta = theta,
-            vcov_theta = vcov_theta,
-            test_phi = test_phi
-          )
+        .MCPhiSigmaI(
+          theta = theta,
+          vcov_theta = vcov_theta,
+          test_phi = test_phi
         )
       }
     )
@@ -223,15 +211,13 @@
                          from,
                          to,
                          med) {
-            return(
-              .MedStd(
-                phi = x[[1]],
-                sigma = x[[2]],
-                delta_t = delta_t,
-                from = from,
-                to = to,
-                med = med
-              )
+            .MedStd(
+              phi = x[[1]],
+              sigma = x[[2]],
+              delta_t = delta_t,
+              from = from,
+              to = to,
+              med = med
             )
           },
           delta_t = i,
@@ -263,14 +249,13 @@
           "indirect",
           "interval"
         )
-        out <- list(
+        list(
           delta_t = i,
           est = est,
           thetahatstar = thetahatstar
         )
-        return(out)
       }
     )
   }
-  return(output)
+  output
 }
