@@ -46,9 +46,7 @@
                 colnames(phi),
                 "interval"
               )
-              return(
-                out
-              )
+              out
             },
             mc.cores = ncores
           )
@@ -56,12 +54,10 @@
             what = "rbind",
             args = thetahatstar
           )
-          return(
-            list(
-              delta_t = i,
-              est = colMeans(thetahatstar),
-              thetahatstar = thetahatstar
-            )
+          list(
+            delta_t = i,
+            est = colMeans(thetahatstar),
+            thetahatstar = thetahatstar
           )
         }
       )
@@ -88,21 +84,17 @@
                 colnames(phi),
                 "interval"
               )
-              return(
-                out
-              )
+              out
             }
           )
           thetahatstar <- do.call(
             what = "rbind",
             args = thetahatstar
           )
-          return(
-            list(
-              delta_t = i,
-              est = colMeans(thetahatstar),
-              thetahatstar = thetahatstar
-            )
+          list(
+            delta_t = i,
+            est = colMeans(thetahatstar),
+            thetahatstar = thetahatstar
           )
         }
       )
@@ -126,24 +118,20 @@
               colnames(phi),
               "interval"
             )
-            return(
-              out
-            )
+            out
           }
         )
         thetahatstar <- do.call(
           what = "rbind",
           args = thetahatstar
         )
-        return(
-          list(
-            delta_t = i,
-            est = colMeans(thetahatstar),
-            thetahatstar = thetahatstar
-          )
+        list(
+          delta_t = i,
+          est = colMeans(thetahatstar),
+          thetahatstar = thetahatstar
         )
       }
     )
   }
-  return(output)
+  output
 }
