@@ -30,7 +30,7 @@ lapply(
         )
         delta_t <- 2
         total <- expm::expm(delta_t * phi)
-        total_cov <- simStateSpace::LinSDECov(
+        total_cov <- simStateSpace::LinSDECovEta(
           phi = phi,
           sigma = sigma
         )
@@ -81,7 +81,7 @@ lapply(
         )
         delta_t <- 2
         total <- expm::expm(delta_t * phi)
-        total_cov <- simStateSpace::LinSDECov(
+        total_cov <- simStateSpace::LinSDECovEta(
           phi = phi,
           sigma = sigma
         )
@@ -137,7 +137,7 @@ lapply(
         )
         delta_t <- 2
         total <- expm::expm(delta_t * phi)
-        total_cov <- simStateSpace::LinSDECov(
+        total_cov <- simStateSpace::LinSDECovEta(
           phi = phi,
           sigma = sigma
         )
@@ -194,7 +194,7 @@ lapply(
         )
         delta_t <- 2
         total <- expm::expm(delta_t * phi)
-        total_cov <- simStateSpace::LinSDECov(
+        total_cov <- simStateSpace::LinSDECovEta(
           phi = phi,
           sigma = sigma
         )
